@@ -72,6 +72,12 @@ def _validate_question(q):  # noqa: CCR001
                 validator_instances.append(v)
         q['validators'] = validator_instances
 
+    if 'disabled' in q:
+        if not (isinstance(q['disabled'], bool) or callable(q['disabled'])):
+            raise InvalidQuestionError(
+                'Disabled flag must be a boolean or callable.',
+            )
+
 
 def validate_questions(questions):
     for q in questions:
